@@ -187,6 +187,11 @@ class ConsoleApi:
         response = self.get(url)
         return response
 
+    def get_automacao_by_constante_virtual_json(self, constante_virtual):
+        url = str(self.url)+"/automacao/executor/"+str(constante_virtual)
+        response = self.get(url)
+        return response
+
     def gravar_log_execucao(self, payload):
         url = str(self.url)+"/logs/"
         
